==> map-1.01.jar: JoinPolygon.java <==
import java.awt.geom.*;

import java.util.*;
import java.util.Map.*;


/*
 * : 2004/01/09
 */

/**
 * ʣο޳Ԥˤޤäݥꥴ򸫤礷
 * ܤ°礵줿ݥꥴ֤륯饹Ǥ
 * @author Kumano Tatsuo
 */
class JoinPolygon {
    private boolean isChanged;

    /** ʣο޳Ԥˤޤäݥꥴ򸫤礷ޤ
     * Υ᥽åɤƤӽФľ isChanged() ƤӽФȡ
     * Υ᥽åɤˤäϿޤξ֤ѲɤǤޤ
     * @param maps Ͽ
     * @throws Exception 㳰
     */
    void joinPolygon(Map maps) throws Exception {
        isChanged = false;

        Map joiningPolygons = new HashMap(); // Map<Polygon = Set<Polygon>>

        for (Iterator iter = maps.entrySet().iterator(); iter.hasNext();) {
            MapData mapData = (MapData) ((Entry) iter.next()).getValue();
            Map edgePolygons = mapData.getEdgePolygons();

            if (edgePolygons != null) {
                for (Iterator iter2 = maps.entrySet().iterator();
                        iter2.hasNext();) {
                    MapData mapData2 = (MapData) ((Entry) iter2.next())
                        .getValue();
                    Map edgePolygons2 = mapData2.getEdgePolygons();

                    if (edgePolygons2 != null) {
                        if (mapData.hashCode() != mapData2.hashCode()) {
                            //System.out.println("1 = " + mapData.getMapName() + ", 2 = " + mapData2.getMapName());
                            //System.out.println("edgePolygons = " + edgePolygons);
                            //System.out.println("edgePolygons2 = " + edgePolygons2);
                            for (Iterator iter3 = edgePolygons.entrySet()
                                                              .iterator();
                                    iter3.hasNext();) {
                                Entry entry3 = (Entry) iter3.next();
                                String key = (String) entry3.getKey();
                                String polygonName = (String) entry3.getValue();

                                if (mapData.hasTyome()) {
                                    if (mapData.getTyome().containsKey(polygonName)) {
                                        PolygonData polygon = (PolygonData) mapData.getTyome()
                                                                                   .get(polygonName);

                                        if (edgePolygons2.containsKey(key)) {
                                            String polygonName2 = (String) edgePolygons2
                                                .get(key);

                                            if (mapData2.hasTyome()) {
                                                Map polygons2 = mapData2
                                                    .getTyome();

                                                if (polygons2.containsKey(
                                                            polygonName2)) {
                                                    if ((polygon.getAttribute() != null)
                                                            && (((PolygonData) polygons2
                                                            .get(polygonName2))
                                                            .getAttribute() != null)) {
                                                        if (polygon.getAttribute()
                                                                       .equals(((PolygonData) polygons2
                                                                    .get(polygonName2))
                                                                    .getAttribute())) {
                                                            //System.out.println(polygonName + " is joining to " + polygonName2);
                                                            if (!joiningPolygons
                                                                    .containsKey(
                                                                        polygon)) {
                                                                joiningPolygons
                                                                .put(polygon,
                                                                    new HashSet());
                                                            }

                                                            ((Set) joiningPolygons
                                                            .get(polygon)).add((PolygonData) polygons2
                                                                .get(polygonName2));
                                                        } else {
                                                            //System.out.println(polygon + "" + polygon2 + "°פޤ");
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }

                                if (mapData.hasZyouti()) {
                                    if (mapData.getZyouti().containsKey(polygonName)) {
                                        PolygonData polygon = (PolygonData) mapData.getZyouti()
                                                                                   .get(polygonName);

                                        if (edgePolygons2.containsKey(key)) {
                                            String polygonName2 = (String) edgePolygons2
                                                .get(key);

                                            if (mapData2.hasZyouti()) {
                                                Map polygons2 = mapData2
                                                    .getZyouti();

                                                if (polygons2.containsKey(
                                                            polygonName2)) {
                                                    if ((polygon.getAttribute() != null)
                                                            && (((PolygonData) polygons2
                                                            .get(polygonName2))
                                                            .getAttribute() != null)) {
                                                        if (polygon.getAttribute()
                                                                       .equals(((PolygonData) polygons2
                                                                    .get(polygonName2))
                                                                    .getAttribute())) {
                                                            //System.out.println(polygonName + " is joining to " + polygonName2);
                                                            if (!joiningPolygons
                                                                    .containsKey(
                                                                        polygon)) {
                                                                joiningPolygons
                                                                .put(polygon,
                                                                    new HashSet());
                                                            }

                                                            ((Set) joiningPolygons
                                                            .get(polygon)).add((PolygonData) polygons2
                                                                .get(polygonName2));
                                                        } else {
                                                            //System.out.println(polygon + "" + polygon2 + "°פޤ");
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }

                                if (mapData.hasMizu()) {
                                    if (mapData.getMizu().containsKey(polygonName)) {
                                        PolygonData polygon = (PolygonData) mapData.getMizu()
                                                                                   .get(polygonName);

                                        if (edgePolygons2.containsKey(key)) {
                                            String polygonName2 = (String) edgePolygons2
                                                .get(key);

                                            if (mapData2.hasMizu()) {
                                                Map polygons2 = mapData2
                                                    .getMizu();

                                                if (polygons2.containsKey(
                                                            polygonName2)) {
                                                    if ((polygon.getAttribute() != null)
                                                            && (((PolygonData) polygons2
                                                            .get(polygonName2))
                                                            .getAttribute() != null)) {
                                                        if (polygon.getAttribute()
                                                                       .equals(((PolygonData) polygons2
                                                                    .get(polygonName2))
                                                                    .getAttribute())) {
                                                            //System.out.println(polygonName + " is joining to " + polygonName2);
                                                            if (!joiningPolygons
                                                                    .containsKey(
                                                                        polygon)) {
                                                                joiningPolygons
                                                                .put(polygon,
                                                                    new HashSet());
                                                            }

                                                            ((Set) joiningPolygons
                                                            .get(polygon)).add((PolygonData) polygons2
                                                                .get(polygonName2));
                                                        } else {
                                                            //System.out.println(polygon + "" + polygon2 + "°פޤ");
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }

        //System.out.println("joining polygons: " + joiningPolygons);
        ArrayList finalPolygons = new ArrayList(); // ArrayList<Set>

        for (Iterator iter = joiningPolygons.entrySet().iterator();
                iter.hasNext();) {
            Entry entry = (Entry) iter.next();
            PolygonData key = (PolygonData) entry.getKey();
            Set values = (Set) entry.getValue();
            boolean isKeyFound = false;

            for (Iterator iter2 = finalPolygons.iterator(); iter2.hasNext();) {
                Set set = (Set) iter2.next();

                if (set.contains(key)) {
                    set.addAll(values);
                    isKeyFound = true;
                }
            }

            for (Iterator iter2 = values.iterator(); iter2.hasNext();) {
                PolygonData value = (PolygonData) iter2.next();

                for (Iterator iter3 = finalPolygons.iterator();
                        iter3.hasNext();) {
                    Set set = (Set) iter3.next();

                    if (set.contains(value)) {
                        set.add(key);
                        set.addAll(values);
                        isKeyFound = true;
                    }
                }
            }

            if (!isKeyFound) {
                Set set = new LinkedHashSet();
                set.add(key);
                set.addAll(values);
                finalPolygons.add(set);
            }
        }

        for (Iterator iter = finalPolygons.iterator(); iter.hasNext();) {
            Set polygons = (Set) iter.next();
            Area area = new Area();

            for (Iterator iter2 = polygons.iterator(); iter2.hasNext();) {
                PolygonData polygon = (PolygonData) iter2.next();

                if (polygon != null) {
                    area.add(polygon.getArea());
                }
            }

            for (Iterator iter2 = polygons.iterator(); iter2.hasNext();) {
                PolygonData polygon = (PolygonData) iter2.next();

                if (polygon != null) {
                    double x = area.getBounds().getCenterX();
                    double y = area.getBounds().getCenterY();

                    if ((polygon.getX() != x) || (polygon.getY() != y)) {
                        polygon.setX(x);
                        polygon.setY(y);
                        isChanged = true;
                    }

                    polygon.setArea(area);
                }
            }
        }
    }

    /**
     * ľηǡϿޤξ֤Ѳɤޤ
     * @return Ͽޤξ֤Ѳɤ
     */
    boolean isChanged() {
        return isChanged;
    }
}

==> map-1.03.jar: JoinPolygon.java <==
import java.awt.geom.*;

import java.util.*;
import java.util.Map.*;


/*
 * 作成日: 2004/01/09
 */

/**
 * 複数の図郭にまたがったポリゴンを見かけ上結合し、
 * 丁目の属性を結合されたポリゴンの中央に配置するクラスです。
 * @author Kumano Tatsuo
 */
class JoinPolygon {
    private boolean isChanged;

    /** 複数の図郭にまたがったポリゴンを見かけ上結合します。
     * このメソッドを呼び出した直後に isChanged() を呼び出すと、
     * このメソッドによって地図の状態が変化したかどうかが取得できます。
     * @param maps 地図
     * @throws Exception 例外
     */
    void joinPolygon(Map maps) throws Exception {
        isChanged = false;

        Map joiningPolygons = new HashMap(); // Map<Polygon = Set<Polygon>>

        for (Iterator iter = maps.entrySet().iterator(); iter.hasNext();) {
            MapData mapData = (MapData) ((Entry) iter.next()).getValue();
            Map edgePolygons = mapData.getEdgePolygons();

            if (edgePolygons != null) {
                for (Iterator iter2 = maps.entrySet().iterator();
                        iter2.hasNext();) {
                    MapData mapData2 = (MapData) ((Entry) iter2.next())
                        .getValue();
                    Map edgePolygons2 = mapData2.getEdgePolygons();

                    if (edgePolygons2 != null) {
                        if (mapData.hashCode() != mapData2.hashCode()) {
                            //System.out.println("1 = " + mapData.getMapName() + ", 2 = " + mapData2.getMapName());
                            //System.out.println("edgePolygons = " + edgePolygons);
                            //System.out.println("edgePolygons2 = " + edgePolygons2);
                            for (Iterator iter3 = edgePolygons.entrySet()
                                                              .iterator();
                                    iter3.hasNext();) {
                                Entry entry3 = (Entry) iter3.next();
                                String key = (String) entry3.getKey();
                                String polygonName = (String) entry3.getValue();

                                if (mapData.hasTyome()) {
                                    if (mapData.getTyome().containsKey(polygonName)) {
                                        PolygonData polygon = (PolygonData) mapData.getTyome()
                                                                                   .get(polygonName);

                                        if (edgePolygons2.containsKey(key)) {
                                            String polygonName2 = (String) edgePolygons2
                                                .get(key);

                                            if (mapData2.hasTyome()) {
                                                Map polygons2 = mapData2
                                                    .getTyome();

                                                if (polygons2.containsKey(
                                                            polygonName2)) {
                                                    if ((polygon.getAttribute() != null)
                                                            && (((PolygonData) polygons2
                                                            .get(polygonName2))
                                                            .getAttribute() != null)) {
                                                        if (polygon.getAttribute()
                                                                       .equals(((PolygonData) polygons2
                                                                    .get(polygonName2))
                                                                    .getAttribute())) {
                                                            //System.out.println(polygonName + " is joining to " + polygonName2);
                                                            if (!joiningPolygons
                                                                    .containsKey(
                                                                        polygon)) {
                                                                joiningPolygons
                                                                .put(polygon,
                                                                    new HashSet());
                                                            }

                                                            ((Set) joiningPolygons
                                                            .get(polygon)).add((PolygonData) polygons2
                                                                .get(polygonName2));
                                                        } else {
                                                            //System.out.println(polygon + "と" + polygon2 + "は属性が一致しません。");
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }

                                if (mapData.hasZyouti()) {
                                    if (mapData.getZyouti().containsKey(polygonName)) {
                                        PolygonData polygon = (PolygonData) mapData.getZyouti()
                                                                                   .get(polygonName);

                                        if (edgePolygons2.containsKey(key)) {
                                            String polygonName2 = (String) edgePolygons2
                                                .get(key);

                                            if (mapData2.hasZyouti()) {
                                                Map polygons2 = mapData2
                                                    .getZyouti();

                                                if (polygons2.containsKey(
                                                            polygonName2)) {
                                                    if ((polygon.getAttribute() != null)
                                                            && (((PolygonData) polygons2
                                                            .get(polygonName2))
                                                            .getAttribute() != null)) {
                                                        if (polygon.getAttribute()
                                                                       .equals(((PolygonData) polygons2
                                                                    .get(polygonName2))
                                                                    .getAttribute())) {
                                                            //System.out.println(polygonName + " is joining to " + polygonName2);
                                                            if (!joiningPolygons
                                                                    .containsKey(
                                                                        polygon)) {
                                                                joiningPolygons
                                                                .put(polygon,
                                                                    new HashSet());
                                                            }

                                                            ((Set) joiningPolygons
                                                            .get(polygon)).add((PolygonData) polygons2
                                                                .get(polygonName2));
                                                        } else {
                                                            //System.out.println(polygon + "と" + polygon2 + "は属性が一致しません。");
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }

                                if (mapData.hasMizu()) {
                                    if (mapData.getMizu().containsKey(polygonName)) {
                                        PolygonData polygon = (PolygonData) mapData.getMizu()
                                                                                   .get(polygonName);

                                        if (edgePolygons2.containsKey(key)) {
                                            String polygonName2 = (String) edgePolygons2
                                                .get(key);

                                            if (mapData2.hasMizu()) {
                                                Map polygons2 = mapData2
                                                    .getMizu();

                                                if (polygons2.containsKey(
                                                            polygonName2)) {
                                                    if ((polygon.getAttribute() != null)
                                                            && (((PolygonData) polygons2
                                                            .get(polygonName2))
                                                            .getAttribute() != null)) {
                                                        if (polygon.getAttribute()
                                                                       .equals(((PolygonData) polygons2
                                                                    .get(polygonName2))
                                                                    .getAttribute())) {
                                                            //System.out.println(polygonName + " is joining to " + polygonName2);
                                                            if (!joiningPolygons
                                                                    .containsKey(
                                                                        polygon)) {
                                                                joiningPolygons
                                                                .put(polygon,
                                                                    new HashSet());
                                                            }

                                                            ((Set) joiningPolygons
                                                            .get(polygon)).add((PolygonData) polygons2
                                                                .get(polygonName2));
                                                        } else {
                                                            //System.out.println(polygon + "と" + polygon2 + "は属性が一致しません。");
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }

        //System.out.println("joining polygons: " + joiningPolygons);
        ArrayList finalPolygons = new ArrayList(); // ArrayList<Set>

        for (Iterator iter = joiningPolygons.entrySet().iterator();
                iter.hasNext();) {
            Entry entry = (Entry) iter.next();
            PolygonData key = (PolygonData) entry.getKey();
            Set values = (Set) entry.getValue();
            boolean isKeyFound = false;

            for (Iterator iter2 = finalPolygons.iterator(); iter2.hasNext();) {
                Set set = (Set) iter2.next();

                if (set.contains(key)) {
                    set.addAll(values);
                    isKeyFound = true;
                }
            }

            for (Iterator iter2 = values.iterator(); iter2.hasNext();) {
                PolygonData value = (PolygonData) iter2.next();

                for (Iterator iter3 = finalPolygons.iterator();
                        iter3.hasNext();) {
                    Set set = (Set) iter3.next();

                    if (set.contains(value)) {
                        set.add(key);
                        set.addAll(values);
                        isKeyFound = true;
                    }
                }
            }

            if (!isKeyFound) {
                Set set = new LinkedHashSet();
                set.add(key);
                set.addAll(values);
                finalPolygons.add(set);
            }
        }

        for (Iterator iter = finalPolygons.iterator(); iter.hasNext();) {
            Set polygons = (Set) iter.next();
            Area area = new Area();

            for (Iterator iter2 = polygons.iterator(); iter2.hasNext();) {
                PolygonData polygon = (PolygonData) iter2.next();

                if (polygon != null) {
                    area.add(polygon.getArea());
                }
            }

            for (Iterator iter2 = polygons.iterator(); iter2.hasNext();) {
                PolygonData polygon = (PolygonData) iter2.next();

                if (polygon != null) {
                    double x = area.getBounds().getCenterX();
                    double y = area.getBounds().getCenterY();

                    if ((polygon.getX() != x) || (polygon.getY() != y)) {
                        polygon.setX(x);
                        polygon.setY(y);
                        isChanged = true;
                    }

                    polygon.setArea(area);
                }
            }
        }
    }

    /**
     * 直前の結合で、地図の状態が変化したかどうかを取得します。
     * @return 地図の状態が変化したかどうか
     */
    boolean isChanged() {
        return isChanged;
    }
}
